/**
  ******************************************************************************
  * @file    user_config.h
  * @author  sinomcu.com-AE
  * @brief   Header file of user config.
  * 
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
 */
// <<< Use Configuration Wizard in Context Menu >>>
#ifndef __USER_CONFIG_H
#define __USER_CONFIG_H

#define USER_VDDA       3300      /* unit mv */
#define ADC_CH_NUM      2         /* used ADC channel number */

// <o> RS485 Baud Rate
// <i> select RS485 baud rate
// <0=>    2400
// <1=>    4800
// <2=>    9600
// <3=>    115200
#define RS485_BAUD_RATE_SELECT    3        

#if (RS485_BAUD_RATE_SELECT == 3) 
#define RS485_BAUD_RATE 116800    /* for 115200，AN2102 2.12, 116800 experience value */
#elif (RS485_BAUD_RATE_SELECT == 2) 
#define RS485_BAUD_RATE 9615      /*for 9600，AN2102 2.12，9615,9900 experience value*/
#elif (RS485_BAUD_RATE_SELECT == 1) 
#define RS485_BAUD_RATE 4800      /*for 4800，AN2102 2.12，4804,4900 experience value*/ 
#else
#define RS485_BAUD_RATE 2401      /*for 2400，AN2102 2.12，2450 experience value*/ 
#endif

// <c1> MCU DE Enable
// <i> Select Enable MCU DE function
#define EN_USART_DE     1         /* 1:USART Hardware DE function,0 GPIO control RS485 driver DE pin by user */
// </c>

//  <o> Driver Enable assertion time
//  <i> unit sample time,0-31,set DE before send 
#define DE_ASSER_TIME   0 

//  <o> Driver Enable de-assertion time
//  <i> unit sample time,0-31,clear DE after send  
#define DE_DASSER_TIME  0

//  <o> Slave ADD
//  <i> Slave address
#define SLAVE_ADD       25

// <c1> Printf to USART
// <i> Retargets printf to USART
#define EN_PRINT_UART   1         /* 1:Retargets printf to USART,0 or not define:printf null out*/
// </c>

// <o> Virtual Uart Baud Rate
// <i> select virtual uart baud rate
// <0=>    9600
// <1=>    38400
// <2=>    115200
#define VIRTUAL_UART_BAUD_SELECT  1        

#if (VIRTUAL_UART_BAUD_SELECT == 2) 
#define VIRTUAL_UART_BAUD 115200 
#elif (VIRTUAL_UART_BAUD_SELECT == 1) 
#define VIRTUAL_UART_BAUD 38400
#else
#define VIRTUAL_UART_BAUD 9600
#endif

#define  Debug_Log    printf

#endif /* __USER_CONFIG_H */
// <<< end of configuration section >>>
/******************************** END OF FILE ******************************** */
